package com.ynet.life.sujrb.base;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.session.Session;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.Trace;
import com.ynet.life.controller.LifeAccessInterface;
import com.ynet.life.controller.LifeClientRequest;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.formValidation.FormValidationProvider;
import com.ynet.life.mvc.SimpleRequest;
import java.security.MessageDigest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.apache.axis.utils.StringUtils;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/PBAccessControl.class */
public class PBAccessControl implements LifeAccessInterface {
    public void checkSubmitTimestamp(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String requestTimestamp = request.getParameter(LifeConstants.FIELD_SUBMIT_TIMESTAMP);
            if (requestTimestamp != null) {
                ArrayList<String> timestampList = (ArrayList) sessionContext.getDataValue(LifeConstants.LIST_SUBMIT_TIMESTAMP);
                if (timestampList != null && timestampList.contains(requestTimestamp)) {
                    Trace.logWarning("LifeAction", "EBLN8000::重复提交异常");
                    throw LifeConstants.EXCEPTION_DUPLICATE_SUBMIT;
                }
                if (timestampList != null) {
                    timestampList.add(requestTimestamp);
                    return;
                }
                ArrayList<String> list = new ArrayList<>();
                list.add(requestTimestamp);
                sessionContext.put(LifeConstants.LIST_SUBMIT_TIMESTAMP, list);
            }
        } catch (GENEException ex) {
            Trace.logError("LifeAction", "时间戳错误", ex);
        } catch (TranFailException ex2) {
            Trace.logError("LifeAction", "EBLN8000::重复提交异常", ex2);
            throw ex2;
        }
    }

    public void checkUserPrivilege(HttpServletRequest request, String mvcName, Context sessionContext) throws TranFailException {
        try {
            Map userPrivilegeMap = (Map) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_TABLE);
            if (userPrivilegeMap == null) {
                Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
            }
            String actionBusinessCode = PBStandard.getActionBusinessCode(String.valueOf(mvcName) + ".do");
            String businessCode = actionBusinessCode;
            if (actionBusinessCode != null) {
                if (!userPrivilegeMap.containsKey(businessCode)) {
                    Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                    throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
                }
                Integer count = (Integer) userPrivilegeMap.get(businessCode);
                userPrivilegeMap.put(businessCode, new Integer(count.intValue() + 1));
            } else {
                String parameter = request.getParameter("linkBusinessCode");
                businessCode = parameter;
                if (parameter == null) {
                    businessCode = (String) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_CODE);
                } else if (!userPrivilegeMap.containsKey(businessCode)) {
                    Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                    throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
                }
            }
            if (businessCode == null) {
                return;
            }
            sessionContext.setDataValue(PBConstants.FIELD_BUSINESS_CODE, businessCode);
        } catch (TranFailException ex) {
            Trace.logError("LifeAction", "交易权限检查异常", ex);
            throw ex;
        } catch (GENEException ex2) {
            Trace.logError("LifeAction", "时间戳错误", ex2);
        }
    }

    public void checkFormValidation(String mvcName, HttpServletRequest request) throws TranFailException {
        TranFailException formValidationConfig = FormValidationProvider.getFormValidationConfig(mvcName);
        if (formValidationConfig != null) {
            try {
                if (!FormValidationProvider.doCheck(FormValidationProvider.getValidationInputMap(formValidationConfig, request))) {
                    Trace.logError("LifeAction", "数据验证失败");
                    formValidationConfig = LifeConstants.EXCEPTION_INVALID_FORMDATA;
                    throw formValidationConfig;
                }
            } catch (TranFailException ex) {
                Trace.log(formValidationConfig);
                throw new TranFailException(ex.getErrorCode(), ex.getShowMessage());
            }
        }
    }

    public void checkHttpGENESID(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String SessionhttpSID = (String) sessionContext.getDataValue("http_sessionId");
            String httpSID = request.getSession().getId();
            if (SessionhttpSID == null || SessionhttpSID == null || !SessionhttpSID.equals(httpSID)) {
                Trace.logWarning("LifeAction", "Session无效，请重新登录！");
                throw new TranFailException("EBLN1001", "Session无效，请重新登录", false);
            }
        } catch (GENEException unused) {
            throw new TranFailException("EBLN1001", "Session无效，请重新登录", false);
        }
    }

    public void checkClientIP(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String sessionClientIP = (String) sessionContext.getDataValue(PBConstants.FIELD_USER_IP);
            String clientIP = LifeClientRequest.getClientIP(request);
            if (sessionClientIP == null || sessionClientIP.length() == 0 || !sessionClientIP.equals(clientIP)) {
                Trace.logWarning("LifeAction", "非法IP地址，请重新登录！");
                throw new TranFailException("EBLN1001", "非法IP地址，请重新登录", false);
            }
        } catch (GENEException unused) {
            throw new TranFailException("EBLN1001", "非法IP地址，请重新登录", false);
        }
    }

    public static void encryptData(Context context, Context sessionContext, SimpleRequest simpleRequest) throws TranFailException {
        Trace.logInfo("LifeAction", "======开始保存交易数据 ==========================]");
        try {
            String operationKey = "OP_TRANS_DATA_" + Long.toHexString(System.currentTimeMillis());
            String privateFields = simpleRequest.getTranFields();
            StringBuffer sb = new StringBuffer();
            if ("LIFE_TOKEN".equals(privateFields)) {
                Trace.logInfo("LifeAction", "======开始保存交易数据 ==privateFields=".concat(String.valueOf(privateFields)));
                Trace.logInfo("LifeAction", "======开始保存交易数据 ==privateFields=" + simpleRequest.getDelimCharField());
                sb.append(privateFields).append(simpleRequest.getDelimCharField());
            } else {
                Trace.logInfo("LifeAction", "======开始保存交易数据 ==privateFields=".concat(String.valueOf(privateFields)));
                Trace.logInfo("LifeAction", "======开始保存交易数据 ==privateFields=" + simpleRequest.getDelimCharField());
                StringTokenizer toke = new StringTokenizer(privateFields, simpleRequest.getDelimCharField());
                while (toke.hasMoreElements()) {
                    sb.append(context.getDataValue(((String) toke.nextElement()).trim())).append(simpleRequest.getDelimCharField());
                }
            }
            sb.append(operationKey);
            String opData = getMD5(sb.toString().getBytes());
            context.put(PBConstants.OPERATION_KEY, operationKey);
            sessionContext.put(operationKey, opData);
            Trace.logInfo("LifeAction", "#encryptData:[" + operationKey + "][" + sb.toString() + "]");
        } catch (GENEException e) {
            Trace.logError("LifeAction", e.getMessage());
            throw new TranFailException("EBLN0000");
        }
    }

    public static void jrbEncryptData(Context context, SimpleRequest simpleRequest, HttpSession session) throws TranFailException {
        long timeNano = System.nanoTime();
        String timeMIllis = String.valueOf(Long.toHexString(timeNano)) + ((int) (Math.random() * 100000.0d));
        Trace.logInfo("LifeAction", "当前时间为：".concat(String.valueOf(timeNano)));
        String operationKey = "OP_TRANS_DATA_".concat(String.valueOf(timeMIllis));
        System.out.println("operationKey============".concat(String.valueOf(operationKey)));
        String privateFields = simpleRequest.getTranFields();
        StringBuffer sb = new StringBuffer();
        sb.append(privateFields).append(simpleRequest.getDelimCharField());
        sb.append(operationKey);
        String opData = getMD5(sb.toString().getBytes());
        if (session.getAttribute(PBConstants.JRB_KEYMAP) == null) {
            HashMap<String, String> map = new HashMap<>();
            map.put(operationKey, opData);
            System.out.println("添加jrbKeyMap元素============".concat(String.valueOf(operationKey)));
            session.setAttribute(PBConstants.JRB_KEYMAP, map);
        } else {
            ((HashMap) session.getAttribute(PBConstants.JRB_KEYMAP)).put(operationKey, opData);
            System.out.println("添加jrbKeyMap元素============".concat(String.valueOf(operationKey)));
        }
        context.put(PBConstants.JRB_KEY, operationKey);
        Trace.logInfo("LifeAction", "#encryptData:[" + operationKey + "][" + sb.toString() + "]");
    }

    public static void verifyData(Context context, Context sessionContext, SimpleRequest simpleRequest) throws TranFailException {
        Trace.logInfo("LifeAction", "======开始验证交易数据 ==========================]");
        try {
            String operationKey = (String) context.get(PBConstants.OPERATION_KEY);
            String verifyData = (String) sessionContext.get(operationKey);
            Trace.logInfo("LifeAction", "======operationKey=" + operationKey + "]");
            Trace.logInfo("LifeAction", "======verifyData=" + verifyData + "]");
            if (operationKey == null || verifyData == null) {
                Trace.logError("LifeAction", "重复提交交易数据，交易失败");
                Trace.logError("LifeAction", "opKey=" + operationKey + "  data=" + verifyData);
                throw new TranFailException("EBLN9000", "重复提交交易数据，交易失败");
            }
            String verifyFields = simpleRequest.getVerifyFields();
            StringBuffer sb = new StringBuffer();
            if ("LIFE_TOKEN".equals(verifyFields)) {
                sb.append(verifyFields).append(simpleRequest.getDelimCharField());
            } else {
                StringTokenizer toke = new StringTokenizer(verifyFields, simpleRequest.getDelimCharField());
                while (toke.hasMoreElements()) {
                    sb.append(context.getDataValue(((String) toke.nextElement()).trim())).append(simpleRequest.getDelimCharField());
                }
            }
            sb.append(operationKey);
            String opData = getMD5(sb.toString().getBytes());
            Trace.logInfo("LifeAction", "#verifyData:[" + operationKey + "][" + sb.toString() + "]");
            if (opData == null || !opData.equals(verifyData)) {
                Trace.logError("LifeAction", "重复提交交易数据，交易失败");
                throw new TranFailException("EBLN9000", "重复提交交易数据，交易失败");
            }
            sessionContext.put(operationKey, (Object) null);
            context.put(PBConstants.OPERATION_KEY, (Object) null);
        } catch (TranFailException e) {
            Trace.logError("LifeAction", e.getMessage());
            throw e;
        } catch (GENEException e2) {
            Trace.logError("LifeAction", e2.getMessage());
            throw new TranFailException("EBLN0000");
        }
    }

    public static void checkVerifyImageInfo(HttpServletRequest request, Session session, SimpleRequest simpleRequest) throws TranFailException {
        String codeField = simpleRequest.getVerifyImageCode();
        if (codeField != null) {
            String code = request.getParameter(codeField);
            String parameter = request.getParameter(PBConstants.PB_TRANCODE);
            String trxCode = parameter;
            if (StringUtils.isEmpty(parameter)) {
                trxCode = "";
            }
            if (code == null || "".equals(code)) {
                Trace.logError("LifeAction", "图形验证码错误未输入，交易失败");
                throw new TranFailException("EBLN9000");
            }
            String confirmCode = (String) session.getAttribute("transferConfirmCode_".concat(String.valueOf(trxCode)));
            if (!code.equalsIgnoreCase(confirmCode)) {
                Trace.logError("LifeAction", "图形验证码错误，请重新输入");
                throw new TranFailException("EBLN5006", "图形验证码错误，请重新输入");
            }
        }
    }

    public static void checkVerifyUserInfo(String sessionClientInfo, String currentClientInfo) throws TranFailException {
        if (!sessionClientInfo.equalsIgnoreCase(currentClientInfo)) {
            Trace.logError("LifeAction", "非法客户访问");
            throw new TranFailException("EBLN5006");
        }
    }

    public void RECORD_USER_BEHAVIOR(HttpServletRequest request, Context sessionContext, String mvcName) {
    }

    public static String getMD5(byte[] source) throws TranFailException {
        String result = null;
        char[] hexDigits = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
        try {
            MessageDigest md = MessageDigest.getInstance("MD5");
            md.update(source);
            byte[] tmp = md.digest();
            char[] str = new char[32];
            int k = 0;
            for (int i = 0; i < 16; i++) {
                byte byte0 = tmp[i];
                int i2 = k;
                int k2 = k + 1;
                str[i2] = hexDigits[(byte0 >>> 4) & 15];
                k = k2 + 1;
                str[k2] = hexDigits[byte0 & 15];
            }
            result = new String(str);
        } catch (Exception e) {
            new TranFailException("EBLN0000", e);
        }
        return result;
    }

    public void checkFlowTrace(String mvcName, Context sessionContext) throws TranFailException {
    }

    public void verifFormData(String mvcName, HttpServletRequest request, Context sessionContext) throws TranFailException {
    }
}
